pub enum Infallible {}Expand description
An Error type that can be used in within an Api definition.
The reason std::convert::Infallible can’t be used is because Api
errors must be able to be serialized across a network connection. While a
value will never be present when this is Infallible, the associated type
still must be declared as Serializable.