Builder

Struct Builder 

pub struct Builder<'a, KeyValue> { /* private fields */ }
Builder for a Command::Get key-value operation.

Implementations

Source

impl<'a, K> Builder<'a, K>
where K: KeyValue,

pub const fn and_delete(self) -> Self

Delete the key after retrieving the value.

pub fn into<V: for<'de> Deserialize<'de>>(self) -> Result<Option<V>, Error>

Deserializes the Value before returning. If the value is a Numeric, an error will be returned.

pub fn into_u64(self) -> Result<Option<u64>, Error>

Converts the Value to an u64 before returning. If the value is not a Numeric, an error will be returned. If the conversion to u64 cannot be done without losing data, an error will be returned.

pub fn into_i64(self) -> Result<Option<i64>, Error>

Converts the Value to an i64 before returning. If the value is not a Numeric, an error will be returned. If the conversion to i64 cannot be done without losing data, an error will be returned.

pub fn into_f64(self) -> Result<Option<f64>, Error>

Converts the Value to an f64 before returning. If the value is not a Numeric, an error will be returned. If the conversion to f64 cannot be done without losing data, an error will be returned.

pub fn into_u64_lossy(self, saturating: bool) -> Result<Option<u64>, Error>

Converts the Value to an u64 before returning. If the value is not a Numeric, an error will be returned. If saturating is true, no overflows will be allowed during conversion.

pub fn into_i64_lossy(self, saturating: bool) -> Result<Option<i64>, Error>

Converts the Value to an i64 before returning. If the value is not a Numeric, an error will be returned. If saturating is true, no overflows will be allowed during conversion.

pub fn into_f64_lossy(self) -> Result<Option<f64>, Error>

Converts the Value to an f64 before returning. If the value is not a Numeric, an error will be returned.

pub fn query(self) -> Result<Option<Value>, Error>

Retrieves the value for the key, using the configured options.