Builder

Struct Builder 

pub struct Builder<'a, KeyValue, V> { /* private fields */ }
Builder for a Command::Set key-value operation.

Implementations

Source

impl<'a, K, V> Builder<'a, K, V>
where K: KeyValue, V: Serialize + Send + Sync,

pub fn expire_in(self, duration: Duration) -> Self

Set this key to expire after duration from now.

pub fn expire_at(self, time: SystemTime) -> Self

Set this key to expire at the provided time.

pub const fn keep_existing_expiration(self) -> Self

If the key already exists, do not update the currently set expiration.

pub const fn only_if_exists(self) -> Self

Only set the value if this key already exists.

pub const fn only_if_vacant(self) -> Self

Only set the value if this key isn’t present.

pub fn returning_previous(self) -> Result<Option<Value>, Error>

Executes the Set operation, requesting the previous value be returned. If no change is made, None will be returned.

pub fn returning_previous_as<OtherV: for<'de> Deserialize<'de>>( self, ) -> Result<Option<OtherV>, Error>

Executes the Set operation, requesting the previous value be returned. If no change is made, None will be returned.

pub fn execute(self) -> Result<KeyStatus, Error>

Executes the operation using the configured options.